@@ -1,8 +1,8 @@
 package Test::LWP::UserAgent;
 {
-  $Test::LWP::UserAgent::VERSION = '0.002';
+  $Test::LWP::UserAgent::VERSION = '0.003';
 }
-# git description: v0.001-14-ge8c2cb0
+# git description: v0.002-2-g0594f34
 
 
 use strict;
@@ -10,7 +10,6 @@ use warnings;
 
 use parent 'LWP::UserAgent';
 use Scalar::Util qw(blessed reftype);
-use re 'is_regexp';
 use Storable 'freeze';
 
 my $last_http_request_sent;
@@ -81,6 +80,8 @@ sub last_http_response_received
         : $last_http_response_received;
 }
 
+sub __is_regexp($);
+
 sub send_request
 {
     my ($self, $request) = @_;
@@ -106,7 +107,7 @@ sub send_request
             $matched_response = $response and last
                 if $request_desc->($request);
         }
-        elsif (is_regexp $request_desc)
+        elsif (__is_regexp $request_desc)
         {
             $matched_response = $response and last
                 if $request->uri =~ $request_desc;
@@ -123,6 +124,11 @@ sub send_request
         ($matched_response || HTTP::Response->new(404));
 }
 
+sub __is_regexp($)
+{
+    $^V < 5.009005 ? ref(shift) eq 'Regexp' : re::is_regexp(shift);
+}
+
 1;
 __END__
 
